Module ingest

Module ingest 

Structs

OwnableEvent
Contract-facing payload for a semantic event emitted by another Ownable.
OwnableEventSource
Identity metadata for the source Ownable of a cross-ownable event.

Enums

OwnableEventError

Functions

require_ownable_event_type
source_matches