pub struct OwnableEvent {
pub source: OwnableEventSource,
pub event_type: String,
pub attributes: Value,
}Expand description
Contract-facing payload for a semantic event emitted by another Ownable.
Fields
source: OwnableEventSourceevent_type: Stringattributes: ValueTrait Implementations
Sourceimpl Clone for OwnableEvent
impl Clone for OwnableEvent
Sourcefn clone(&self) -> OwnableEvent
fn clone(&self) -> OwnableEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OwnableEvent
impl Debug for OwnableEvent
Sourceimpl<'de> Deserialize<'de> for OwnableEvent
impl<'de> Deserialize<'de> for OwnableEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for OwnableEvent
impl JsonSchema for OwnableEvent
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for OwnableEvent
impl PartialEq for OwnableEvent
Sourcefn eq(&self, other: &OwnableEvent) -> bool
fn eq(&self, other: &OwnableEvent) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for OwnableEvent
impl Serialize for OwnableEvent
impl StructuralPartialEq for OwnableEvent