pub struct OwnableEventSource {
pub id: String,
pub owner: String,
pub issuer: String,
}Expand description
Identity metadata for the source Ownable of a cross-ownable event.
Fields
id: Stringowner: Stringissuer: StringTrait Implementations
Sourceimpl Clone for OwnableEventSource
impl Clone for OwnableEventSource
Sourcefn clone(&self) -> OwnableEventSource
fn clone(&self) -> OwnableEventSource
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OwnableEventSource
impl Debug for OwnableEventSource
Sourceimpl<'de> Deserialize<'de> for OwnableEventSource
impl<'de> Deserialize<'de> for OwnableEventSource
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for OwnableEventSource
impl JsonSchema for OwnableEventSource
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for OwnableEventSource
impl PartialEq for OwnableEventSource
Sourcefn eq(&self, other: &OwnableEventSource) -> bool
fn eq(&self, other: &OwnableEventSource) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for OwnableEventSource
impl Serialize for OwnableEventSource
impl Eq for OwnableEventSource
impl StructuralPartialEq for OwnableEventSource