Structs
Functions
- derive_
rgb_ values - takes a hex-encoded hash and derives a seemingly-random rgb tuple
- get_
random_ color - returns a hex color in string format from a hash
- package_
title_ from_ name - convert an ownable package name into a display title
e.g.
ownable-my-first->My First - rgb_hex
- takes three u8 values representing rgb values (0-255)f and returns a hex string