pub struct EncodePublicEventRequest {
pub event_type: String,
pub data: Binary,
}Expand description
Request payload for JS-driven public-event ABI encoding.
Fields
event_type: Stringdata: BinaryTrait Implementations
Sourceimpl Clone for EncodePublicEventRequest
impl Clone for EncodePublicEventRequest
Sourcefn clone(&self) -> EncodePublicEventRequest
fn clone(&self) -> EncodePublicEventRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EncodePublicEventRequest
impl Debug for EncodePublicEventRequest
Sourceimpl<'de> Deserialize<'de> for EncodePublicEventRequest
impl<'de> Deserialize<'de> for EncodePublicEventRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EncodePublicEventRequest
impl JsonSchema for EncodePublicEventRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for EncodePublicEventRequest
impl PartialEq for EncodePublicEventRequest
Sourcefn eq(&self, other: &EncodePublicEventRequest) -> bool
fn eq(&self, other: &EncodePublicEventRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for EncodePublicEventRequest
impl Serialize for EncodePublicEventRequest
impl Eq for EncodePublicEventRequest
impl StructuralPartialEq for EncodePublicEventRequest