pub struct EmptyApi { /* private fields */ }Trait Implementations
Sourceimpl Api for EmptyApi
impl Api for EmptyApi
Sourcefn addr_validate(&self, human: &str) -> StdResult<Addr>
fn addr_validate(&self, human: &str) -> StdResult<Addr>
Takes a human readable address and validates if it is valid.
If it the validation succeeds, a
Addr containing the same data as the input is returned. Read moreSourcefn addr_canonicalize(&self, human: &str) -> StdResult<CanonicalAddr>
fn addr_canonicalize(&self, human: &str) -> StdResult<CanonicalAddr>
Takes a human readable address and returns a canonical binary representation of it.
This can be used when a compact representation is needed. Read more
Sourcefn addr_humanize(&self, canonical: &CanonicalAddr) -> StdResult<Addr>
fn addr_humanize(&self, canonical: &CanonicalAddr) -> StdResult<Addr>
Takes a canonical address and returns a human readable address.
This is the inverse of
addr_canonicalize.fn secp256k1_verify( &self, _message_hash: &[u8], _signature: &[u8], _public_key: &[u8], ) -> Result<bool, VerificationError>
fn secp256k1_recover_pubkey( &self, _message_hash: &[u8], _signature: &[u8], _recovery_param: u8, ) -> Result<Vec<u8>, RecoverPubkeyError>
fn ed25519_verify( &self, _message: &[u8], _signature: &[u8], _public_key: &[u8], ) -> Result<bool, VerificationError>
fn ed25519_batch_verify( &self, _messages: &[&[u8]], _signatures: &[&[u8]], _public_keys: &[&[u8]], ) -> Result<bool, VerificationError>
Sourcefn debug(&self, message: &str)
fn debug(&self, message: &str)
Emits a debugging message that is handled depending on the environment (typically printed to console or ignored).
Those messages are not persisted to chain.
Sourcefn bls12_381_aggregate_g1(
&self,
g1s: &[u8],
) -> Result<[u8; 48], VerificationError>
fn bls12_381_aggregate_g1( &self, g1s: &[u8], ) -> Result<[u8; 48], VerificationError>
Add up points of the G1 subgroup on the BLS12-381 curve Read more
Sourcefn bls12_381_aggregate_g2(
&self,
g2s: &[u8],
) -> Result<[u8; 96], VerificationError>
fn bls12_381_aggregate_g2( &self, g2s: &[u8], ) -> Result<[u8; 96], VerificationError>
Add up points of the G2 subgroup on the BLS12-381 curve Read more
Sourcefn bls12_381_pairing_equality(
&self,
ps: &[u8],
qs: &[u8],
r: &[u8],
s: &[u8],
) -> Result<bool, VerificationError>
fn bls12_381_pairing_equality( &self, ps: &[u8], qs: &[u8], r: &[u8], s: &[u8], ) -> Result<bool, VerificationError>
Checks the following pairing equality: Read more
Sourcefn bls12_381_hash_to_g1(
&self,
hash_function: HashFunction,
msg: &[u8],
dst: &[u8],
) -> Result<[u8; 48], VerificationError>
fn bls12_381_hash_to_g1( &self, hash_function: HashFunction, msg: &[u8], dst: &[u8], ) -> Result<[u8; 48], VerificationError>
Take some arbitrary data and hash it to a point on the G1 subgroup of the curve. Read more
Sourcefn bls12_381_hash_to_g2(
&self,
hash_function: HashFunction,
msg: &[u8],
dst: &[u8],
) -> Result<[u8; 96], VerificationError>
fn bls12_381_hash_to_g2( &self, hash_function: HashFunction, msg: &[u8], dst: &[u8], ) -> Result<[u8; 96], VerificationError>
Take some arbitrary data and hash it to a point on the G2 subgroup of the curve. Read more
fn secp256r1_verify( &self, message_hash: &[u8], signature: &[u8], public_key: &[u8], ) -> Result<bool, VerificationError>
fn secp256r1_recover_pubkey( &self, message_hash: &[u8], signature: &[u8], recovery_param: u8, ) -> Result<Vec<u8>, RecoverPubkeyError>
impl Copy for EmptyApi