pub struct IdbStorage {
pub storage: MemoryStorage,
}Expand description
Wrapper around MemoryStorage with helpers to load state from browser IndexedDB dumps.
Fields
storage: MemoryStorageImplementations
Sourceimpl IdbStorage
impl IdbStorage
Sourcepub fn load(idb: IdbStateDump) -> Self
pub fn load(idb: IdbStateDump) -> Self
Creates a new IdbStorage and populates it from a serialized state dump.
Sourcepub fn load_to_mem_storage(&mut self, idb_state: IdbStateDump)
pub fn load_to_mem_storage(&mut self, idb_state: IdbStateDump)
takes a IdbStateDump and loads the values into MemoryStorage