Skip to main contentModule storage
Source - EmptyApi
- EmptyQuerier
- Empty Querier that is meant to conform the traits expected by the cosmwasm standard contract syntax. It should not be used whatsoever
- IdbStateDump
- Serialized contract storage dump used to move state between JS and Rust.
- IdbStorage
- Wrapper around
MemoryStorage with helpers to load state from browser IndexedDB dumps. - MemoryStorage
- In-memory
Storage implementation used for tests and host-side execution.
- load_owned_deps
- Builds in-memory dependencies for contract execution, optionally preloaded from IndexedDB dump data.